@@ -22,15 +22,14 @@
 #include "extractHereDndPlugin.h"
 #include "ark_debug.h"
 #include "batchextract.h"
-#include "kerfuffle/archive_kerfuffle.h"
+#include "archive_kerfuffle.h"
 #include "pluginmanager.h"
 
 #include <QAction>
-#include <QDebug>
 
+#include <KFileItemListProperties>
 #include <KPluginFactory>
 #include <KPluginLoader>
-#include <kfileitemlistproperties.h>
 #include <KLocalizedString>
 
 K_PLUGIN_FACTORY_WITH_JSON(ExtractHereDndPluginFactory, "ark_dndextract.json",
@@ -73,7 +72,7 @@ QList<QAction *> ExtractHereDndPlugin::setup(const KFileItemListProperties& popu
     qCDebug(ARK) << "Plugin executed";
 
     QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("archive-extract")),
-                                  extractHereMessage, NULL);
+                                  extractHereMessage, nullptr);
     connect(action, &QAction::triggered, this, &ExtractHereDndPlugin::slotTriggered);
 
     actionList.append(action);
