@@ -36,20 +36,20 @@ class MainWindow: public KParts::MainWindow
 {
     Q_OBJECT
 public:
-    explicit MainWindow(QWidget *parent = 0);
-    ~MainWindow();
+    explicit MainWindow(QWidget *parent = nullptr);
+    ~MainWindow() override;
     bool loadPart();
 
-    void dragEnterEvent(class QDragEnterEvent * event) Q_DECL_OVERRIDE;
-    void dropEvent(class QDropEvent * event) Q_DECL_OVERRIDE;
-    void dragMoveEvent(class QDragMoveEvent * event) Q_DECL_OVERRIDE;
+    void dragEnterEvent(class QDragEnterEvent * event) override;
+    void dropEvent(class QDropEvent * event) override;
+    void dragMoveEvent(class QDragMoveEvent * event) override;
 
 public slots:
     void openUrl(const QUrl &url);
     void setShowExtractDialog(bool);
 
 protected:
-    void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *event) override;
 
 private slots:
     void updateActions();
@@ -58,6 +58,7 @@ private slots:
     void quit();
     void showSettings();
     void writeSettings();
+    void addPartUrl();
 
 private:
     void setupActions();
