@@ -25,8 +25,7 @@
  */
 
 #include "jsonarchiveinterface.h"
-#include "kerfuffle/jobs.h"
-#include "kerfuffle/archiveentry.h"
+#include "jobs.h"
 
 #include <KPluginMetaData>
 
@@ -76,7 +75,7 @@ private:
 QTEST_GUILESS_MAIN(JobsTest)
 
 JobsTest::JobsTest()
-    : QObject(Q_NULLPTR)
+    : QObject(nullptr)
     , m_eventLoop(this)
 {
 }
@@ -97,7 +96,7 @@ JSONArchiveInterface *JobsTest::createArchiveInterface(const QString& filePath)
                                                                   QVariant().fromValue(KPluginMetaData())});
     if (!iface->open()) {
         qDebug() << "Could not open" << filePath;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     return iface;
