@@ -27,7 +27,6 @@
 #define ARCHIVEENTRY_H
 
 #include "archive_kerfuffle.h"
-#include "app/ark_debug.h"
 
 #include <QDateTime>
 
@@ -72,8 +71,8 @@ class Archive::Entry : public QObject
 
 public:
 
-    explicit Entry(QObject *parent = Q_NULLPTR, const QString &fullPath = {}, const QString &rootNode = {});
-    ~Entry();
+    explicit Entry(QObject *parent = nullptr, const QString &fullPath = {}, const QString &rootNode = {});
+    ~Entry() override;
 
     void copyMetaData(const Archive::Entry *sourceEntry);
 
@@ -92,7 +91,12 @@ public:
     int row() const;
     Entry *find(const QString &name) const;
     Entry *findByPath(const QStringList & pieces, int index = 0) const;
-    void returnDirEntries(QVector<Entry*> *store);
+
+    /**
+     * Fills @p dirs and @p files with the number of directories and files
+     * in the entry (both will be 0 if the entry is not a directory).
+     */
+    void countChildren(uint &dirs, uint &files) const;
 
     bool operator==(const Archive::Entry &right) const;
 
