@@ -41,7 +41,7 @@ Plugin::Plugin(QObject *parent, const KPluginMetaData &metaData)
 {
 }
 
-unsigned int Plugin::priority() const
+int Plugin::priority() const
 {
     const int priority = m_metaData.rawData()[QStringLiteral("X-KDE-Priority")].toInt();
     return (priority > 0 ? priority : 0);
@@ -93,9 +93,14 @@ KPluginMetaData Plugin::metaData() const
     return m_metaData;
 }
 
+bool Plugin::hasRequiredExecutables() const
+{
+    return findExecutables(readOnlyExecutables());
+}
+
 bool Plugin::isValid() const
 {
-    return isEnabled() && m_metaData.isValid() && findExecutables(readOnlyExecutables());
+    return isEnabled() && m_metaData.isValid() && hasRequiredExecutables();
 }
 
 bool Plugin::findExecutables(const QStringList &executables)
