@@ -44,5 +44,14 @@ QString SettingsPage::iconName() const
 {
     return m_iconName;
 }
+
+void SettingsPage::slotSettingsChanged()
+{
+}
+
+void SettingsPage::slotDefaultsButtonClicked()
+{
+}
+
 }
 
