@@ -43,6 +43,7 @@ ArkViewer::ArkViewer()
 
     setupUi(this);
 
+    m_buttonBox->button(QDialogButtonBox::Close)->setShortcut(Qt::Key_Escape);
     // Bug 369390: This prevents the Enter key from closing the window.
     m_buttonBox->button(QDialogButtonBox::Close)->setAutoDefault(false);
 
@@ -102,7 +103,7 @@ void ArkViewer::view(const QString& fileName)
         return;
     }
 
-    qCDebug(ARK) << "Using internal viewer";
+    qCDebug(ARK) << "Attempting to use internal viewer";
     bool viewInInternalViewer = true;
     if (!viewer) {
         // No internal viewer available for the file.  Ask the user if it
@@ -172,7 +173,7 @@ bool ArkViewer::viewInInternalViewer(const QString& fileName, const QMimeType &m
     setWindowFilePath(fileName);
 
     // Set icon and comment for the mimetype.
-    m_iconLabel->setPixmap(QIcon::fromTheme(mimeType.iconName()).pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)));
+    m_iconLabel->setPixmap(QIcon::fromTheme(mimeType.iconName()).pixmap(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small)));
     m_commentLabel->setText(mimeType.comment());
 
     // Create the ReadOnlyPart instance.
@@ -180,6 +181,7 @@ bool ArkViewer::viewInInternalViewer(const QString& fileName, const QMimeType &m
 
     // Drop the KHTMLPart, if necessary.
     const KService::Ptr service = KMimeTypeTrader::self()->preferredService(mimeType.name(), QStringLiteral("KParts/ReadOnlyPart"));
+    qCDebug(ARK) << "Preferred service for mimetype" << mimeType.name() << "is" << service->library();
     if (service.constData()->desktopEntryName() == QLatin1String("khtml")) {
         KService::List offers = KMimeTypeTrader::self()->query(mimeType.name(), QStringLiteral("KParts/ReadOnlyPart"));
         offers.removeFirst();
