@@ -25,7 +25,7 @@
 #define PART_H
 
 #include "interface.h"
-#include "kerfuffle/archiveentry.h"
+#include "archiveentry.h"
 
 #include <KParts/Part>
 #include <KParts/ReadWritePart>
@@ -35,6 +35,7 @@
 #include <QModelIndex>
 
 class ArchiveModel;
+class ArchiveSortFilterModel;
 class ArchiveView;
 class InfoPanel;
 
@@ -44,6 +45,7 @@ class KJob;
 class KToggleAction;
 
 class QAction;
+class QLineEdit;
 class QSplitter;
 class QTreeView;
 class QTemporaryDir;
@@ -52,6 +54,7 @@ class QSignalMapper;
 class QFileSystemWatcher;
 class QGroupBox;
 class QPlainTextEdit;
+class QPushButton;
 
 namespace Ark
 {
@@ -68,14 +71,15 @@ public:
     };
 
     Part(QWidget *parentWidget, QObject *parent, const QVariantList &);
-    ~Part();
+    ~Part() override;
 
-    bool openFile() Q_DECL_OVERRIDE;
-    bool saveFile() Q_DECL_OVERRIDE;
+    bool openFile() override;
+    bool saveFile() override;
 
-    bool isBusy() const Q_DECL_OVERRIDE;
-    KConfigSkeleton *config() const Q_DECL_OVERRIDE;
-    QList<Kerfuffle::SettingsPage*> settingsPages(QWidget *parent) const Q_DECL_OVERRIDE;
+    bool isBusy() const override;
+    KConfigSkeleton *config() const override;
+    QList<Kerfuffle::SettingsPage*> settingsPages(QWidget *parent) const override;
+    bool eventFilter(QObject *target, QEvent *event) override;
 
     /**
      * Validate the localFilePath() associated to this part.
@@ -94,9 +98,10 @@ public slots:
     void extractSelectedFilesTo(const QString& localPath);
 
 protected:
-    void guiActivateEvent(KParts::GUIActivateEvent *event) Q_DECL_OVERRIDE;
+    void guiActivateEvent(KParts::GUIActivateEvent *event) override;
 
 private slots:
+    void slotCompleted();
     void slotLoadingStarted();
     void slotLoadingFinished(KJob *job);
     void slotOpenExtractedEntry(KJob*);
@@ -130,7 +135,6 @@ private slots:
     void slotPasteFiles(QVector<Kerfuffle::Archive::Entry*> &files, Kerfuffle::Archive::Entry *destination, int entriesWithoutChildren);
 
     void slotAddFiles();
-    void slotEditFileName();
     void slotCutFiles();
     void slotCopyFiles();
     void slotRenameFile(const QString &name);
@@ -156,7 +160,9 @@ private slots:
     void slotAddComment();
     void slotCommentChanged();
     void slotTestArchive();
+    void slotShowFind();
     void displayMsgWidget(KMessageWidget::MessageType type, const QString& msg);
+    void searchEdited(const QString &text);
 
 signals:
     void busy();
@@ -164,17 +170,27 @@ signals:
     void quit();
 
 private:
+    /**
+     * @return true if both the current archive and the part are read-write, false otherwise.
+     */
+    bool isArchiveWritable() const;
+
+    /**
+     * @return Whether the part has been told to create a new archive.
+     */
+    bool isCreatingNewArchive() const;
+
     void createArchive();
     void loadArchive();
     void resetGui();
     void setupView();
     void setupActions();
-    bool isSingleFolderArchive() const;
     QString detectSubfolder() const;
     QVector<Kerfuffle::Archive::Entry*> filesForIndexes(const QModelIndexList& list) const;
     QVector<Kerfuffle::Archive::Entry*> filesAndRootNodesForIndexes(const QModelIndexList& list) const;
     QModelIndexList addChildren(const QModelIndexList &list) const;
     void registerJob(KJob *job);
+    QModelIndexList getSelectedIndexes();
 
     ArchiveModel         *m_model;
     ArchiveView          *m_view;
@@ -193,6 +209,7 @@ private:
     QAction *m_propertiesAction;
     QAction *m_editCommentAction;
     QAction *m_testArchiveAction;
+    QAction *m_searchAction;
     KToggleAction *m_showInfoPanelAction;
     InfoPanel            *m_infoPanel;
     QSplitter            *m_splitter;
@@ -216,6 +233,10 @@ private:
     KMessageWidget *m_commentMsgWidget;
     KMessageWidget *m_messageWidget;
     Kerfuffle::CompressionOptions m_compressionOptions;
+    ArchiveSortFilterModel *m_filterModel;
+    QWidget *m_searchWidget;
+    QLineEdit *m_searchLineEdit;
+    QPushButton *m_searchCloseButton;
 };
 
 } // namespace Ark
