@@ -23,8 +23,7 @@
 #ifndef CLIPLUGIN_H
 #define CLIPLUGIN_H
 
-#include "kerfuffle/archiveentry.h"
-#include "kerfuffle/cliinterface.h"
+#include "cliinterface.h"
 
 class CliPlugin : public Kerfuffle::CliInterface
 {
@@ -32,13 +31,13 @@ class CliPlugin : public Kerfuffle::CliInterface
 
 public:
     explicit CliPlugin(QObject *parent, const QVariantList &args);
-    virtual ~CliPlugin();
+    ~CliPlugin() override;
 
-    virtual bool list() Q_DECL_OVERRIDE;
-    virtual bool extractFiles(const QVector<Kerfuffle::Archive::Entry*> &files, const QString &destinationDirectory, const Kerfuffle::ExtractionOptions &options) Q_DECL_OVERRIDE;
-    virtual void resetParsing() Q_DECL_OVERRIDE;
-    virtual bool readListLine(const QString &line) Q_DECL_OVERRIDE;
-    virtual bool readExtractLine(const QString &line) Q_DECL_OVERRIDE;
+    bool list() override;
+    bool extractFiles(const QVector<Kerfuffle::Archive::Entry*> &files, const QString &destinationDirectory, const Kerfuffle::ExtractionOptions &options) override;
+    void resetParsing() override;
+    bool readListLine(const QString &line) override;
+    bool readExtractLine(const QString &line) override;
 
     /**
      * Fill the lsar's json output all in once (useful for unit testing).
@@ -46,14 +45,14 @@ public:
     void setJsonOutput(const QString &jsonOutput);
 
 protected slots:
-    void readStdout(bool handleAll = false) Q_DECL_OVERRIDE;
+    void readStdout(bool handleAll = false) override;
 
 protected:
 
-    bool handleLine(const QString& line) Q_DECL_OVERRIDE;
+    bool handleLine(const QString& line) override;
 
 private slots:
-    void processFinished(int exitCode, QProcess::ExitStatus exitStatus) Q_DECL_OVERRIDE;
+    void processFinished(int exitCode, QProcess::ExitStatus exitStatus) override;
 
 private:
     void setupCliProperties();
