@@ -28,8 +28,7 @@
 #ifndef LIBARCHIVEPLUGIN_H
 #define LIBARCHIVEPLUGIN_H
 
-#include "kerfuffle/archiveinterface.h"
-#include "kerfuffle/archiveentry.h"
+#include "archiveinterface.h"
 
 #include <archive.h>
 
@@ -43,19 +42,19 @@ class LibarchivePlugin : public ReadWriteArchiveInterface
 
 public:
     explicit LibarchivePlugin(QObject *parent, const QVariantList &args);
-    virtual ~LibarchivePlugin();
+    ~LibarchivePlugin() override;
 
-    virtual bool list() Q_DECL_OVERRIDE;
-    virtual bool doKill() Q_DECL_OVERRIDE;
-    virtual bool extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options) Q_DECL_OVERRIDE;
+    bool list() override;
+    bool doKill() override;
+    bool extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options) override;
 
-    virtual bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions &options, uint numberOfEntriesToAdd = 0) Q_DECL_OVERRIDE;
-    virtual bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) Q_DECL_OVERRIDE;
-    virtual bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) Q_DECL_OVERRIDE;
-    virtual bool deleteFiles(const QVector<Archive::Entry*> &files) Q_DECL_OVERRIDE;
-    virtual bool addComment(const QString &comment) Q_DECL_OVERRIDE;
-    virtual bool testArchive() Q_DECL_OVERRIDE;
-    virtual bool hasBatchExtractionProgress() const Q_DECL_OVERRIDE;
+    bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions &options, uint numberOfEntriesToAdd = 0) override;
+    bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) override;
+    bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) override;
+    bool deleteFiles(const QVector<Archive::Entry*> &files) override;
+    bool addComment(const QString &comment) override;
+    bool testArchive() override;
+    bool hasBatchExtractionProgress() const override;
 
 protected:
     struct ArchiveReadCustomDeleter
