@@ -42,12 +42,12 @@ class ReadWriteLibarchivePlugin : public LibarchivePlugin
 
 public:
     explicit ReadWriteLibarchivePlugin(QObject *parent, const QVariantList &args);
-    ~ReadWriteLibarchivePlugin();
+    ~ReadWriteLibarchivePlugin() override;
 
-    bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions &options, uint numberOfEntriesToAdd = 0) Q_DECL_OVERRIDE;
-    bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) Q_DECL_OVERRIDE;
-    bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) Q_DECL_OVERRIDE;
-    bool deleteFiles(const QVector<Archive::Entry*> &files) Q_DECL_OVERRIDE;
+    bool addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions &options, uint numberOfEntriesToAdd = 0) override;
+    bool moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) override;
+    bool copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options) override;
+    bool deleteFiles(const QVector<Archive::Entry*> &files) override;
 
 protected:
     bool initializeWriter(const bool creatingNewFile = false, const CompressionOptions &options = CompressionOptions());
@@ -64,7 +64,7 @@ private:
      *
      * @return bool indicating whether the operation was successful.
      */
-    bool processOldEntries(int &entriesCounter, OperationMode mode, uint totalCount);
+    bool processOldEntries(uint &entriesCounter, OperationMode mode, uint totalCount);
 
     /**
      * Writes entry being read into memory.
@@ -90,7 +90,7 @@ private:
     // Passed argument from job which is used by processOldEntries method.
     QStringList m_filesPaths;
     int m_entriesWithoutChildren = 0;
-    const Archive::Entry *m_destination = Q_NULLPTR;
+    const Archive::Entry *m_destination = nullptr;
 };
 
 #endif // READWRITELIBARCHIVEPLUGIN_H
